@@ -27,7 +27,6 @@ typedef struct  {gint count; gint max;} counter;
 
 static GcomprisBoard *gcomprisBoard = NULL;
 static gboolean board_paused = TRUE;
-static SoundPolicy sound_policy;
 static GdkPixbuf *CoverPixmap[MAX_LAYERS];
 static gulong event_handle_id;
 
@@ -57,8 +56,9 @@ static guint normal_delay_id = 0;
 
 static gint timer_id = 0;
 
-#define NORMAL 0
-#define CLIC   1
+#define NORMAL     0
+#define CLIC       1
+#define DOUBLECLIC 2
 
 static gint board_mode =  NORMAL;
 
@@ -189,6 +189,8 @@ static void start_board (GcomprisBoard *agcomprisBoard)
 
       if (strcmp(gcomprisBoard->mode,"clic")==0)
 	board_mode = CLIC;
+      else if (strcmp(gcomprisBoard->mode,"doubleclic")==0)
+	board_mode = DOUBLECLIC;
       else {
 	board_mode = NORMAL;
 	gcomprisBoard->maxlevel=8;
@@ -202,10 +204,6 @@ static void start_board (GcomprisBoard *agcomprisBoard)
       gamewon = FALSE;
       pause_board(FALSE);
 
-      /* initial state to restore */
-      sound_policy = gc_sound_policy_get();
-      gc_sound_policy_set(PLAY_AND_INTERRUPT);
-
       GdkPixbuf *cursor_pixbuf = gc_pixmap_load("images/sponge.png");
       if(cursor_pixbuf)
 	{
@@ -239,7 +237,6 @@ static void end_board ()
       erase_destroy_all_items();
     }
   gcomprisBoard = NULL;
-  gc_sound_policy_set(sound_policy);
 }
 
 /* ======================================= */
@@ -449,6 +446,8 @@ erase_one_item (GnomeCanvasItem *item)
 {
   double screen_x, screen_y;
   int x,y;
+  SoundPolicy sound_policy = gc_sound_policy_get();
+
   g_object_get(item, "x", &screen_x, "y", &screen_y, NULL);
   x = screen_x / (BOARDWIDTH/number_of_item_x);
   y = screen_y / (BOARDHEIGHT/number_of_item_y);
@@ -457,17 +456,26 @@ erase_one_item (GnomeCanvasItem *item)
 
   gtk_object_destroy(GTK_OBJECT(item));
 
-  if(number_of_items%2)
-    gc_sound_play_ogg ("sounds/eraser1.wav", NULL);
-  else
-    gc_sound_play_ogg ("sounds/eraser2.wav", NULL);
-
   if(--number_of_items == 0)
     {
       gamewon = TRUE;
       erase_destroy_all_items();
       timer_id = gtk_timeout_add (4000, (GtkFunction) bonus, NULL);
     }
+
+  /* force a cleanup of the sound queue */
+  if(number_of_items == 0)
+      gc_sound_policy_set(PLAY_AND_INTERRUPT);
+
+  if(number_of_items%2)
+    gc_sound_play_ogg ("sounds/eraser1.wav", NULL);
+  else
+    gc_sound_play_ogg ("sounds/eraser2.wav", NULL);
+
+  if(number_of_items == 0)
+    gc_sound_policy_set(sound_policy);
+
+
   normal_delay_id = 0;
   return FALSE;
 }
@@ -476,7 +484,10 @@ erase_one_item (GnomeCanvasItem *item)
 static gint
 item_event(GnomeCanvasItem *item, GdkEvent *event, gpointer data)
 {
+  static GnomeCanvasItem *previous_clicked_item = NULL;
+  static guint32 previous_click_time = 0;
   counter *c = (counter *) data;
+
   if(board_paused)
     return FALSE;
 
@@ -505,6 +516,26 @@ item_event(GnomeCanvasItem *item, GdkEvent *event, gpointer data)
     if (event->type != GDK_BUTTON_PRESS)
       return FALSE;
 
+  if (board_mode == DOUBLECLIC)
+    {
+      if (event->type != GDK_BUTTON_PRESS)
+	return FALSE;
+      else
+	{
+	  guint32 d = event->button.time - previous_click_time;
+	  /* Click duration handicap depending on the level */
+	  d += gcomprisBoard->level * 100;
+
+	  if (previous_clicked_item != item
+	      || d >= 850)
+	    {
+	      previous_clicked_item = item;
+	      previous_click_time = event->button.time;
+	      return FALSE;
+	    }
+	}
+    }
+
   erase_one_item (item);
 
   return FALSE;
