@@ -52,7 +52,6 @@ typedef struct {
 } Board;
 
 /* XML */
-static gboolean		 read_xml_file(char *fname);
 static void		 init_xml(void);
 static void		 add_xml_data(xmlDocPtr doc,xmlNodePtr xmlnode, GNode * child);
 static void		 parse_doc(xmlDocPtr doc);
@@ -554,8 +553,8 @@ static void add_xml_data(xmlDocPtr doc, xmlNodePtr xmlnode, GNode * child)
 {
   gchar *pixmapfile = NULL;
   gchar *text1 = NULL, *text2 = NULL, *text3 = NULL;
+  xmlChar* tmp;
   Board * board = g_new(Board,1);
-  gboolean found_text1 = FALSE, found_text2 = FALSE, found_text3 = FALSE;
 
   xmlnode = xmlnode->xmlChildrenNode;
 
@@ -566,30 +565,33 @@ static void add_xml_data(xmlDocPtr doc, xmlNodePtr xmlnode, GNode * child)
     if (!strcmp((char *)xmlnode->name, "pixmapfile"))
       pixmapfile = (gchar *)xmlNodeListGetString(doc, xmlnode->xmlChildrenNode, 1);
 
-    if (!found_text1 && !strcmp((char *)xmlnode->name, "text1"))
+    if (!strcmp((char *)xmlnode->name, "text1"))
       {
 	if(text1==NULL)
 	  {
-	    text1 = \
-	      g_strdup(gettext((gchar *)xmlNodeListGetString(doc, xmlnode->xmlChildrenNode, 1)));
+	    tmp = xmlNodeListGetString(doc, xmlnode->xmlChildrenNode, 1);
+	    text1 = g_strdup(gettext((gchar*)tmp));
+	    g_free(tmp);
 	  }
       }
 
-    if (!found_text2 && !strcmp((char *)xmlnode->name, "text2"))
+    if (!strcmp((char *)xmlnode->name, "text2"))
       {
 	if(text2==NULL)
 	  {
-	    text2 = \
-	      g_strdup(gettext((gchar *)xmlNodeListGetString(doc, xmlnode->xmlChildrenNode, 1)));
+	    tmp = xmlNodeListGetString(doc, xmlnode->xmlChildrenNode, 1);
+	    text2 = g_strdup(gettext((gchar*)tmp));
+	    g_free(tmp);
 	  }
       }
 
-    if (!found_text3 && !strcmp((char *)xmlnode->name, "text3"))
+    if (!strcmp((char *)xmlnode->name, "text3"))
       {
 	if(text3==NULL)
 	  {
-	    text3 = \
-	      g_strdup(gettext((gchar *)xmlNodeListGetString(doc, xmlnode->xmlChildrenNode, 1)));
+	    tmp = xmlNodeListGetString(doc, xmlnode->xmlChildrenNode, 1);
+	    text3 = g_strdup(gettext((gchar *)tmp));
+	    g_free(tmp);
 	  }
       }
 
@@ -630,7 +632,7 @@ static gboolean read_xml_file(char *fname)
   g_return_val_if_fail(fname!=NULL,FALSE);
 
   /* parse the new file and put the result into newdoc */
-  doc = gc_net_load_xml(fname);
+  doc = xmlParseFile(fname);
 
   /* in case something went wrong */
   if(!doc)
@@ -748,8 +750,8 @@ config_start(GcomprisBoard *agcomprisBoard,
   gchar *label = g_strdup_printf(_("<b>%s</b> configuration\n for profile <b>%s</b>"),
 				 agcomprisBoard->name,
 				 aProfile ? aProfile->name : "");
-
-  gc_board_config_window_display( label,
+  GcomprisBoardConf *bconf;
+  bconf = gc_board_config_window_display( label,
 				 (GcomprisConfCallback )conf_ok);
 
   g_free(label);
@@ -759,7 +761,7 @@ config_start(GcomprisBoard *agcomprisBoard,
 
   gchar *locale = g_hash_table_lookup( config, "locale");
 
-  gc_board_config_combo_locales( locale);
+  gc_board_config_combo_locales(bconf, locale);
 
 }
 
