@@ -1,6 +1,4 @@
 /* gcompris - memory.c
- *
- * Time-stamp: <2007-08-22 01:26:19 bruno>
  *
  * Copyright (C) 2000 Bruno Coudoin
  *
@@ -165,9 +163,9 @@ static guint levelDescription[] =
   0,0,
   3,2,
   4,2,
+  5,2,
   4,3,
   6,3,
-  4,4,
   5,4,
   6,4,
   7,4,
@@ -236,16 +234,16 @@ static gchar *soundList[] =
    "sounds/LuneRouge/usine/LRHits_01_by_Lionel_Allorge.ogg",
    "sounds/chronos/space/1.ogg",
    "sounds/chronos/space/2.ogg",
-   "sounds/melody/guitar/melody.ogg",
-   "sounds/melody/guitar/son1.ogg",
-   "sounds/melody/guitar/son2.ogg",
-   "sounds/melody/guitar/son3.ogg",
-   "sounds/melody/guitar/son4.ogg",
-   "sounds/melody/tachos/melody.ogg",
-   "sounds/melody/tachos/son1.ogg",
-   "sounds/melody/tachos/son2.ogg",
-   "sounds/melody/tachos/son3.ogg",
-   "sounds/melody/tachos/son4.ogg",
+   "sounds/melody/guitar/melody.wav",
+   "sounds/melody/guitar/son1.wav",
+   "sounds/melody/guitar/son2.wav",
+   "sounds/melody/guitar/son3.wav",
+   "sounds/melody/guitar/son4.wav",
+   "sounds/melody/tachos/melody.wav",
+   "sounds/melody/tachos/son1.wav",
+   "sounds/melody/tachos/son2.wav",
+   "sounds/melody/tachos/son3.wav",
+   "sounds/melody/tachos/son4.wav",
    "sounds/memory/plick.ogg",
    "sounds/memory/tick.ogg",
    "sounds/memory/tri.ogg",
@@ -288,6 +286,7 @@ static BoardPlugin menu_bp =
  */
 
 static gboolean to_tux = FALSE;
+static gboolean lock_user = FALSE;
 static GQueue *tux_memory;
 static gint tux_memory_size;
 static gint tux_memory_sizes[] = { 0, 1, 2, 3, 4, 5, 6, 7, 8, 9 };
@@ -397,8 +396,6 @@ static GList *passed_token = NULL;
 static GnomeCanvasItem *tux;
 static GnomeCanvasItem *tux_score;
 static GnomeCanvasItem *player_score;
-static GnomeCanvasItem *tux_score_s;
-static GnomeCanvasItem *player_score_s;
 
 /* set the type of the token returned in string in returned_type */
 void get_random_token(int token_type, gint *returned_type, gchar **string, gchar **second_value)
@@ -867,13 +864,6 @@ static void start_board (GcomprisBoard *agcomprisBoard)
 
       Paused = FALSE;
 
-      to_tux = FALSE;
-      if (currentUiMode == UIMODE_SOUND){
-	playing_sound = TRUE;
-	gc_sound_play_ogg_cb("sounds/LuneRouge/musique/LRBuddhist_gong_05_by_Lionel_Allorge.ogg",start_callback);
-      } else
-	playing_sound = FALSE;
-
       memory_next_level();
     }
 }
@@ -947,8 +937,6 @@ static void update_scores()
 
   gnome_canvas_item_set(tux_score,      "text", tux_score_str, NULL);
   gnome_canvas_item_set(player_score,   "text", player_score_str, NULL);
-  gnome_canvas_item_set(tux_score_s,    "text", tux_score_str, NULL);
-  gnome_canvas_item_set(player_score_s, "text", player_score_str, NULL);
 
   g_free(tux_score_str);
   g_free(player_score_str);
@@ -959,6 +947,15 @@ static void memory_next_level()
 {
   gc_bar_set_level(gcomprisBoard);
 
+  to_tux = FALSE;
+  if (currentUiMode == UIMODE_SOUND){
+    /* We play a sound here to cancel any pending sounds callback from a previous play */
+    playing_sound = TRUE;
+    gc_sound_play_ogg_cb("sounds/LuneRouge/musique/LRBuddhist_gong_05_by_Lionel_Allorge.ogg",
+			 start_callback);
+  } else
+    playing_sound = FALSE;
+
   memory_destroy_all_items();
 
   boardRootItem = GNOME_CANVAS_GROUP(
@@ -977,6 +974,8 @@ static void memory_next_level()
 
   create_item(boardRootItem);
 
+  lock_user = FALSE;
+
   if (currentMode == MODE_TUX){
 	tux_memory_size = tux_memory_sizes[gcomprisBoard->level];
 	g_warning("tux_memory_size %d", tux_memory_size );
@@ -1002,11 +1001,11 @@ static void memory_destroy_all_items()
   win_id = 0;
 
   if (currentMode == MODE_TUX){
+    to_tux = FALSE;
     if (tux_id) {
       g_source_remove (tux_id);
     }
     tux_id =0;
-    to_tux = FALSE;
   }
 
   /* Now destroy all items */
@@ -1213,34 +1212,16 @@ static void create_item(GnomeCanvasGroup *parent)
     tux = gnome_canvas_item_new (GNOME_CANVAS_GROUP(parent),
 				 gnome_canvas_pixbuf_get_type (),
 				 "pixbuf", pixmap_tux,
-				 "x", (double) 50,
-				 "y", (double) 20,
+				 "x", (double) 35,
+				 "y", (double) 240,
 				 NULL);
     gdk_pixbuf_unref(pixmap_tux);
 
-    tux_score_s = gnome_canvas_item_new (GNOME_CANVAS_GROUP(parent),
-				       gnome_canvas_text_get_type (),
-				       "font", gc_skin_font_board_huge_bold,
-				       "x", (double) 100+1.0,
-				       "y", (double) 200+1.0,
-				       "anchor", GTK_ANCHOR_CENTER,
-				       "fill_color_rgba", 0x101010FF,
-				       NULL);
-
-    player_score_s = gnome_canvas_item_new (GNOME_CANVAS_GROUP(parent),
-					  gnome_canvas_text_get_type (),
-					  "font", gc_skin_font_board_huge_bold,
-					  "x", (double) 100+1.0,
-					  "y", (double) BASE_CARD_Y2 - 20+1.0,
-					  "anchor", GTK_ANCHOR_CENTER,
-					  "fill_color_rgba", 0x101010FF,
-					  NULL);
-
     tux_score = gnome_canvas_item_new (GNOME_CANVAS_GROUP(parent),
 				       gnome_canvas_text_get_type (),
 				       "font", gc_skin_font_board_huge_bold,
 				       "x", (double) 100,
-				       "y", (double) 200,
+				       "y", (double) 340,
 				       "anchor", GTK_ANCHOR_CENTER,
 				       "fill_color_rgba", 0xFF0F0FFF,
 				       NULL);
@@ -1448,7 +1429,10 @@ static gint hide_card (GtkWidget *widget, gpointer data)
     GList *to_remove = NULL;
 
     for (list =  winning_pairs; list != NULL; list=list->next)
-      if ((((WINNING *) list->data)->first == firstCard) || (((WINNING *) list->data)->first == secondCard) || (((WINNING *) list->data)->second == firstCard) || (((WINNING *) list->data)->second == secondCard) ){
+      if ((((WINNING *) list->data)->first == firstCard) ||
+	  (((WINNING *) list->data)->first == secondCard) ||
+	  (((WINNING *) list->data)->second == firstCard) ||
+	  (((WINNING *) list->data)->second == secondCard) ){
 	to_remove = g_list_append( to_remove, list->data);
       }
 
@@ -1490,9 +1474,9 @@ static gint hide_card (GtkWidget *widget, gpointer data)
   if(remainingCards<=0){
     if (currentMode == MODE_TUX){
       if (tux_id){
+	to_tux = FALSE;
 	g_source_remove(tux_id);
 	tux_id = 0;
-	to_tux = FALSE;
       }
     }
     player_win();
@@ -1515,20 +1499,23 @@ static void check_win()
     timeout_tux = 2000;
   }
 
+
   // Check win
   if (compare_card((gpointer) firstCard, (gpointer) secondCard) == 0) {
     gc_sound_play_ogg ("sounds/flip.wav", NULL);
     win_id = g_timeout_add (timeout,
 			    (GSourceFunc) hide_card, NULL);
+    lock_user = FALSE;
     return;
   }
 
   if (currentMode == MODE_TUX){
-		 /* time to tux to play, after a delay */
+    /* time to tux to play, after a delay */
     to_tux = TRUE;
     g_warning("Now tux will play !");
     tux_id = g_timeout_add (timeout_tux,
 			    (GSourceFunc) tux_play, NULL);
+    lock_user = FALSE;
     return;
   }
 
@@ -1549,7 +1536,7 @@ item_event(GnomeCanvasItem *item, GdkEvent *event, MemoryItem *memoryItem)
          case 1:
 
 	   if (currentMode == MODE_TUX){
-	     if (to_tux){
+	     if (to_tux || lock_user){
 	       g_warning("He ! it's tux turn !");
 	       return FALSE;
 	     }
@@ -1592,10 +1579,12 @@ item_event(GnomeCanvasItem *item, GdkEvent *event, MemoryItem *memoryItem)
 	       if (currentMode == MODE_TUX)
 		 add_card_in_tux_memory(memoryItem);
 	       display_card(memoryItem, ON_FRONT);
-	       if (currentUiMode == UIMODE_SOUND)
+	       if (currentUiMode == UIMODE_SOUND) {
 		 // Check win is called from callback return
+		 // The user lost, make sure she won't play again before tux
+		 lock_user = TRUE;
 		 return TRUE;
-	       else {
+	       } else {
 		 check_win();
 		 return TRUE;
 	       }
@@ -1685,6 +1674,9 @@ static gint tux_play(){
     return TRUE;
   }
 
+  if ( ! to_tux )
+    return TRUE;
+
   g_warning("Now tux playing !");
 
   if(secondCard)
@@ -1698,7 +1690,6 @@ static gint tux_play(){
   if (winning_pairs){
     g_warning("I will won !");
     if (!firstCard){
-      g_warning("case 1");
       firstCard = ((WINNING *) winning_pairs->data)->first ;
       display_card(firstCard, ON_FRONT);
       if (currentUiMode == UIMODE_SOUND)
@@ -1706,7 +1697,6 @@ static gint tux_play(){
       else
 	return TRUE;
     } else {
-      g_warning("case 2");
       secondCard = ((WINNING *) winning_pairs->data)->second;
       display_card(secondCard, ON_FRONT);
       if (currentUiMode == UIMODE_SOUND)
@@ -1748,7 +1738,6 @@ static gint tux_play(){
     }
 
   if (!firstCard){
-    g_warning("case 3");
     firstCard = memoryArray[rx][ry];
     add_card_in_tux_memory(firstCard);
     display_card(firstCard, ON_FRONT);
@@ -1758,7 +1747,6 @@ static gint tux_play(){
     else
       return TRUE;
   } else {
-    g_warning("case 4");
     secondCard = memoryArray[rx][ry];
     add_card_in_tux_memory(secondCard);
     display_card(secondCard, ON_FRONT);
@@ -1785,7 +1773,8 @@ static void sound_callback(gchar *file)
   if (! gcomprisBoard)
     return;
 
-  g_warning("sound_callback %s", file);
+  if (!playing_sound)
+    return;
 
   playing_sound = FALSE;
   if (currentMode == MODE_TUX){
