@@ -6,7 +6,7 @@
 #
 #   This program is free software; you can redistribute it and/or modify
 #   it under the terms of the GNU General Public License as published by
-#   the Free Software Foundation; either version 2 of the License, or
+#   the Free Software Foundation; either version 3 of the License, or
 #   (at your option) any later version.
 #
 #   This program is distributed in the hope that it will be useful,
@@ -15,8 +15,7 @@
 #   GNU General Public License for more details.
 #
 #   You should have received a copy of the GNU General Public License
-#   along with this program; if not, write to the Free Software
-#   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+#   along with this program; if not, see <http://www.gnu.org/licenses/>.
 #
 import gnomecanvas
 import gcompris
@@ -521,8 +520,12 @@ class Gcompris_bargame:
 
     def set_prof(self, prof_image):
       self.prof_item.set(pixbuf = gcompris.utils.load_pixmap(prof_image))
+      self.prof_image = prof_image
 
     def event_play(self, item, event):
+      if event.type == gtk.gdk.LEAVE_NOTIFY:
+        self.set_prof(self.prof_image)
+
       if ((event.type != gtk.gdk.BUTTON_PRESS) or
           (event.button != 1)):
         return False
