@@ -1,7 +1,5 @@
 #  gcompris - connect4
 #
-# Time-stamp:
-#
 # Copyright (C) 2005 Laurent Lacheny
 #
 #   This program is free software; you can redistribute it and/or modify
@@ -31,7 +29,7 @@ import gcompris.bonus
 import gcompris.anim
 import gtk
 import gtk.gdk
-from gettext import gettext as _
+from gcompris import gcompris_gettext as _
 
 from  connect4p import rules
 from  connect4p import human
@@ -351,7 +349,7 @@ class Gcompris_connect4:
             width_pixels = 8
             )
         self.redLine.set_property("cap-style", gtk.gdk.CAP_ROUND)
-        if player == 1:
+        if player == 1 or self.mode == 2:
             gcompris.bonus.display(gcompris.bonus.WIN, gcompris.bonus.FLOWER)
         elif player == 2:
             gcompris.bonus.display(gcompris.bonus.LOOSE, gcompris.bonus.FLOWER)
