@@ -1,6 +1,4 @@
 /* gcompris - reading.c
- *
- * Time-stamp: <2007-08-22 01:27:18 bruno>
  *
  * Copyright (C) 2000 Bruno Coudoin
  *
@@ -46,7 +44,8 @@ static GnomeCanvasGroup *boardRootItem = NULL;
 typedef enum
 {
   MODE_HORIZONTAL		= 0,
-  MODE_VERTICAL			= 1
+  MODE_VERTICAL			= 1,
+  MODE_HORIZONTAL_RTL		= 2
 } Mode;
 static Mode currentMode = MODE_VERTICAL;
 
@@ -210,10 +209,9 @@ static void start_board (GcomprisBoard *agcomprisBoard)
 
       g_warning ("Font to display words have size %d  ascent : %d, descent : %d.\n Set inerline to %d", font_size, ascent, descent, interline);
 
-      /* Default mode */
-      currentMode=MODE_VERTICAL;
-      if(gcomprisBoard->mode && g_strcasecmp(gcomprisBoard->mode, "horizontal")==0)
-	currentMode=MODE_HORIZONTAL;
+
+
+
 
       gc_wordlist = gc_wordlist_get_from_file("wordsgame/default-$LOCALE.xml");
 
@@ -230,7 +228,17 @@ static void start_board (GcomprisBoard *agcomprisBoard)
 	    }
 	}
 
-      reading_next_level();
+
+      currentMode=MODE_VERTICAL; // Default mode
+      if(gcomprisBoard->mode && g_strcasecmp(gcomprisBoard->mode, "horizontal")==0)
+        {
+          if (pango_unichar_direction(g_utf8_get_char(gc_wordlist_random_word_get(gc_wordlist, gcomprisBoard->level))) == PANGO_DIRECTION_RTL)
+              currentMode=MODE_HORIZONTAL_RTL;
+          else
+               currentMode=MODE_HORIZONTAL;
+        }
+
+       reading_next_level();
     }
 }
 
@@ -314,7 +322,7 @@ static gint reading_next_level()
     }
   else
     {
-      current_x = BASE_X1;
+      current_x = BASE_X2;
       numberOfLine=2+gcomprisBoard->level;
     }
 
@@ -447,7 +455,15 @@ static gboolean reading_create_item(GnomeCanvasGroup *parent)
       word = g_strdup(textToFind);
     }
 
-  g_assert(word!=NULL);
+  if(word==NULL)
+  {
+  	gc_dialog(_("We skip this level because there are not enough words in the list!"),
+		(DialogBoxCallBack)reading_next_level);
+	gcomprisBoard->level++;
+	if(gcomprisBoard->level>gcomprisBoard->maxlevel) // the current board is finished : bail out
+		gc_bonus_end_display(GC_BOARD_FINISHED_RANDOM);
+	return FALSE;
+  }
 
   if(textToFindIndex>=0)
     textToFindIndex--;
@@ -461,6 +477,8 @@ static gboolean reading_create_item(GnomeCanvasGroup *parent)
 
   if(currentMode==MODE_HORIZONTAL)
     anchor=GTK_ANCHOR_WEST;
+  else if (currentMode==MODE_HORIZONTAL_RTL)
+    anchor=GTK_ANCHOR_EAST;
 
   previousFocus.item = \
     gnome_canvas_item_new (GNOME_CANVAS_GROUP(previousFocus.rootItem),
@@ -497,6 +515,24 @@ static gboolean reading_create_item(GnomeCanvasGroup *parent)
       current_y += interline;
       numberOfLine--;
     }
+  else if (currentMode==MODE_HORIZONTAL_RTL)
+    {
+      double x1, y1, x2, y2;
+
+      gnome_canvas_item_get_bounds(GNOME_CANVAS_ITEM(previousFocus.rootItem), &x1, &y1, &x2, &y2);
+
+      // Are we out of bound
+      if(x1<BASE_X1)
+	{
+	  // Do the line Wrapping
+	  gnome_canvas_item_move(GNOME_CANVAS_ITEM(previousFocus.rootItem), BASE_X2-x2, interline);
+	  current_y += interline;
+	  current_x = BASE_X2;
+	  numberOfLine--;
+	}
+      current_x -= x2-x1 + font_size;
+     }
+
   else
     {
       double x1, y1, x2, y2;
@@ -564,7 +600,6 @@ static void ask_ready(gboolean status)
 				"y", y_offset,
 				NULL);
 
-  gdk_pixbuf_unref(button_pixmap);
   gtk_signal_connect(GTK_OBJECT(item1), "event",
 		     (GtkSignalFunc) item_event_valid,
 		     "R");
@@ -580,6 +615,7 @@ static void ask_ready(gboolean status)
 				"fill_color", "white",
 				NULL);
 
+  gdk_pixbuf_unref(button_pixmap);
   gtk_signal_connect(GTK_OBJECT(item2), "event",
 		     (GtkSignalFunc) item_event_valid,
 		     "R");
@@ -604,7 +640,6 @@ static void ask_yes_no()
 				"y", y_offset,
 				NULL);
 
-  gdk_pixbuf_unref(button_pixmap);
   gtk_signal_connect(GTK_OBJECT(item), "event",
 		     (GtkSignalFunc) item_event_valid,
 		     "Y");
@@ -626,7 +661,6 @@ static void ask_yes_no()
 
   /*----- NO -----*/
   y_offset += 100;
-  button_pixmap = gc_skin_pixmap_load("button_large2.png");
   item = gnome_canvas_item_new (boardRootItem,
 				gnome_canvas_pixbuf_get_type (),
 				"pixbuf",  button_pixmap,
@@ -634,7 +668,6 @@ static void ask_yes_no()
 				"y", y_offset,
 				NULL);
 
-  gdk_pixbuf_unref(button_pixmap);
   gtk_signal_connect(GTK_OBJECT(item), "event",
 		     (GtkSignalFunc) item_event_valid,
 		     "N");
@@ -650,6 +683,7 @@ static void ask_yes_no()
 				"fill_color", "white",
 				NULL);
 
+  gdk_pixbuf_unref(button_pixmap);
   gtk_signal_connect(GTK_OBJECT(item), "event",
 		     (GtkSignalFunc) item_event_valid,
 		     "N");
@@ -748,6 +782,7 @@ static gchar *
 get_random_word(const gchar* except)
 {
   gchar *word;
+  int count=0;
 
   word = gc_wordlist_random_word_get(gc_wordlist, gcomprisBoard->level);
 
@@ -755,6 +790,12 @@ get_random_word(const gchar* except)
     while(strcmp(except, word)==0)
       {
 	g_free(word);
+
+	if(count++>100)
+	{
+		word = NULL;
+		break;
+	}
 	word = gc_wordlist_random_word_get(gc_wordlist, gcomprisBoard->level);
       }
 
@@ -823,6 +864,7 @@ static void
 reading_config_start(GcomprisBoard *agcomprisBoard,
 		    GcomprisProfile *aProfile)
 {
+  GcomprisBoardConf *conf;
   board_conf = agcomprisBoard;
   profile_conf = aProfile;
 
@@ -833,7 +875,7 @@ reading_config_start(GcomprisBoard *agcomprisBoard,
 				 agcomprisBoard->name,
 				 aProfile? aProfile->name: "");
 
-  gc_board_config_window_display( label,
+  conf = gc_board_config_window_display( label,
 				 (GcomprisConfCallback )conf_ok);
 
   g_free(label);
@@ -843,8 +885,8 @@ reading_config_start(GcomprisBoard *agcomprisBoard,
 
   gchar *locale = g_hash_table_lookup( config, "locale");
 
-  gc_board_config_combo_locales( locale);
-
+  gc_board_config_combo_locales(conf, locale);
+  gc_board_config_wordlist(conf, "wordsgame/default-$LOCALE.xml");
 }
 
 
