@@ -1,6 +1,4 @@
 /* gcompris - shapegame.c
- *
- * Time-stamp: <2007-08-22 01:25:02 bruno>
  *
  * Copyright (C) 2000 Bruno Coudoin
  *
@@ -434,6 +432,7 @@ static void shapegame_next_level()
   char *filename;
 
   gamewon = FALSE;
+  gc_drag_stop(gnome_canvas_root(gcomprisBoard->canvas));
 
   shapegame_destroy_all_items();
   next_shapelist_item = previous_shapelist_item = NULL;
@@ -456,6 +455,8 @@ static void shapegame_next_level()
 
   read_xml_file(filename);
 
+
+  gc_drag_start(gnome_canvas_root(gcomprisBoard->canvas), (gc_Drag_Func) item_event_drag, drag_mode);
   g_free(filename);
 }
 
@@ -949,16 +950,20 @@ static gint item_event_drag(GnomeCanvasItem *item, GdkEvent *event, gpointer dat
                          * of sound rather than a single one */
                         char *p = NULL;
                         char *soundfile = g_strdup(shape->soundfile);
+			char *soundfiles = soundfile;
 
-                        while ((p = strstr (soundfile, " ")))
+                        while ((p = strstr (soundfiles, " ")))
                         {
                             *p='\0';
-                            gc_sound_play_ogg(soundfile, NULL);
-                            soundfile=p+1;
-                            g_warning("soundfile = %s\n", soundfile);
+                            gc_sound_play_ogg(soundfiles, NULL);
+                            soundfiles= p + 1;
+                            g_warning("soundfile = %s\n", soundfiles);
                         }
 
-                        gc_sound_play_ogg(soundfile, NULL);
+			if (soundfiles != soundfile)
+			  gc_sound_play_ogg(soundfiles, NULL);
+			else
+			  gc_sound_play_ogg(soundfile, NULL);
 			g_free(soundfile);
                     }
 		    else
@@ -1739,7 +1744,7 @@ read_xml_file(char *fname)
   g_return_val_if_fail(fname!=NULL,FALSE);
 
   /* parse the new file and put the result into newdoc */
-  doc = gc_net_load_xml(fname);
+  doc = xmlParseFile(fname);
   /* in case something went wrong */
   if(!doc)
     return FALSE;
@@ -1867,7 +1872,8 @@ config_start(GcomprisBoard *agcomprisBoard,
 				  agcomprisBoard->name,
 				  aProfile? aProfile->name : "");
 
-  gc_board_config_window_display( label,
+  GcomprisBoardConf *bconf;
+  bconf = gc_board_config_window_display( label,
 				 (GcomprisConfCallback )conf_ok);
 
   g_free(label);
@@ -1878,7 +1884,7 @@ config_start(GcomprisBoard *agcomprisBoard,
   if (strcmp(agcomprisBoard->name, "imagename")==0){
     gchar *locale = g_hash_table_lookup( config, "locale");
 
-    gc_board_config_combo_locales( locale);
+    gc_board_config_combo_locales( bconf, locale);
   }
 
   gchar *drag_mode_str = g_hash_table_lookup( config, "drag_mode");
@@ -1889,7 +1895,7 @@ config_start(GcomprisBoard *agcomprisBoard,
   else
     drag_previous = 0;
 
-  gc_board_config_combo_drag( drag_mode);
+  gc_board_config_combo_drag(bconf, drag_mode);
 
 }
 
