@@ -79,6 +79,10 @@ static gboolean		 wordsgame_destroy_items(GPtrArray *items);
 static void		 wordsgame_destroy_all_items(void);
 static void		 wordsgame_next_level(void);
 static void		 wordsgame_add_new_item(void);
+static void		 wordsgame_config_start(GcomprisBoard *agcomprisBoard,
+					     GcomprisProfile *aProfile);
+static void		 wordsgame_config_stop(void);
+
 
 static void		 player_win(LettersItem *item);
 static void		 player_loose(void);
@@ -121,8 +125,8 @@ static BoardPlugin menu_bp =
     set_level,
     NULL,
     NULL,
-    NULL,
-    NULL
+    wordsgame_config_start,
+    wordsgame_config_stop
   };
 
 /*
@@ -186,7 +190,7 @@ static void start_board (GcomprisBoard *agcomprisBoard)
       gcomprisBoard->level = 1;
       gcomprisBoard->maxlevel = 6;
       gcomprisBoard->sublevel = 0;
-      gc_bar_set(GC_BAR_LEVEL);
+      gc_bar_set(GC_BAR_LEVEL|GC_BAR_CONFIG);
 
       /* Default speed */
       speed=DEFAULT_SPEED;
@@ -649,9 +653,14 @@ static GnomeCanvasItem *wordsgame_create_item(GnomeCanvasGroup *parent)
                                    &y2);
 
   if(direction_anchor == GTK_ANCHOR_NW)
-    gnome_canvas_item_move (item->rootitem,(double) (g_random_int()%(gcomprisBoard->width-(gint)(x2))),(double) 0);
+      gnome_canvas_item_move (item->rootitem,(double) (g_random_int()%(gcomprisBoard->width-(gint)(x2))),(double) 0);
   else
-    gnome_canvas_item_move (item->rootitem,(double) (g_random_int()%(gcomprisBoard->width+(gint)(x2))),(double) 0);
+   {
+      double new_x = (double)( g_random_int()%gcomprisBoard->width); 
+      if ( new_x < -x1 )      
+		new_x -=  x1;
+      gnome_canvas_item_move (item->rootitem, new_x ,(double) 0);
+   }
 
   g_static_rw_lock_writer_lock (&items_lock);
   g_ptr_array_add(items, item);
@@ -754,3 +763,30 @@ static void player_loose()
 {
   gc_sound_play_ogg ("sounds/crash.wav", NULL);
 }
+
+static void conf_ok(gpointer data)
+{
+	pause_board(FALSE);
+}
+
+static void wordsgame_config_start(GcomprisBoard *agcomprisBoard, GcomprisProfile *aProfile)
+{
+	if (gcomprisBoard)
+		pause_board(TRUE);
+
+	gchar *label = g_strdup_printf(_("<b>%s</b> configuration\n for profile <b>%s</b>"),
+			agcomprisBoard->name,
+			aProfile? aProfile->name: "");
+	GcomprisBoardConf *bconf;
+	bconf = gc_board_config_window_display( label,
+			(GcomprisConfCallback )conf_ok);
+
+	g_free(label);
+
+	gc_board_config_wordlist(bconf, "wordsgame/default-$LOCALE.xml");
+}
+
+static void wordsgame_config_stop(void)
+{
+}
+
