@@ -1,6 +1,4 @@
 /* gcompris - config.c
- *
- * Time-stamp: <2007-08-22 01:21:16 bruno>
  *
  * Copyright (C) 2000-2003 Bruno Coudoin
  *
@@ -67,26 +65,25 @@ static gchar *linguas[] = {
   "cs_CZ.UTF-8",	N_("Czech Republic"),
   "da_DK.UTF-8", 	N_("Danish"),
   "de_DE.UTF-8", 	N_("German"),
+  "dz_BT.UTF-8",	N_("Dzongkha"),
   "el_GR.UTF-8", 	N_("Greek"),
   "en_CA.UTF-8",	N_("English (Canada)"),
   "en_GB.UTF-8",	N_("English (Great Britain)"),
   "en_US.UTF-8",	N_("English (United States)"),
   "es_ES.UTF-8", 	N_("Spanish"),
   "eu_ES.UTF-8",	N_("Basque"),
-  "dz_BT.UTF-8",	N_("Dzongkha"),
   "fa_IR.UTF-8", 	N_("Persian"),
   "fi_FI.UTF-8", 	N_("Finnish"),
   "fr_FR.UTF-8", 	N_("French"),
   "ga_IE.UTF-8", 	N_("Irish (Gaelic)"),
+  "gu_IN.UTF-8",	N_("Gujarati"),
   "he_IL.UTF-8",	N_("Hebrew"),
   "hi_IN.UTF-8",	N_("Hindi"),
-  "id_ID.UTF-8",	N_("Indonesian"),
-  "ja_JP.UTF-8",	N_("Japanese"),
-  "gu_IN.UTF-8",	N_("Gujarati"),
-  "pa_IN.UTF-8",	N_("Punjabi"),
-  "hu_HU.UTF-8",	N_("Hungarian"),
   "hr_HR.UTF-8",	N_("Croatian"),
+  "hu_HU.UTF-8",	N_("Hungarian"),
+  "id_ID.UTF-8",	N_("Indonesian"),
   "it_IT.UTF-8", 	N_("Italian"),
+  "ja_JP.UTF-8",	N_("Japanese"),
   "ka_GE.UTF-8",        N_("Georgian"),
   "ko_KR.UTF-8",        N_("Korean"),
   "lt_LT.UTF-8",	N_("Lithuanian"),
@@ -94,14 +91,15 @@ static gchar *linguas[] = {
   "ml_IN.UTF-8",	N_("Malayalam"),
   "mr_IN.UTF-8",	N_("Marathi"),
   "ms_MY.UTF-8",	N_("Malay"),
+  "nb_NO.UTF-8",	N_("Norwegian Bokmal"),
   "ne_NP.UTF-8",	N_("Nepal"),
   "nl_NL.UTF-8",	N_("Dutch"),
-  "nb_NO.UTF-8",	N_("Norwegian Bokmal"),
   "nn_NO.UTF-8",	N_("Norwegian Nynorsk"),
   "oc_FR.UTF-8",	N_("Occitan (languedocien)"),
+  "pa_IN.UTF-8",	N_("Punjabi"),
   "pl_PL.UTF-8",	N_("Polish"),
-  "pt_PT.UTF-8",	N_("Portuguese"),
   "pt_BR.UTF-8",	N_("Portuguese (Brazil)"),
+  "pt_PT.UTF-8",	N_("Portuguese"),
   "ro_RO.UTF-8",	N_("Romanian"),
   "ru_RU.UTF-8",	N_("Russian"),
   "rw_RW.UTF-8",	N_("Kinyarwanda"),
@@ -115,8 +113,8 @@ static gchar *linguas[] = {
   "ta_IN.UTF-8",	N_("Tamil"),
   "th_TH.UTF-8",	N_("Thai"),
   "tr_TR.UTF-8",	N_("Turkish"),
-  "ur_PK.UTF-8",	N_("Urdu"),
   "uk_UA.UTF8",		N_("Ukrainian"),
+  "ur_PK.UTF-8",	N_("Urdu"),
   "vi_VN.UTF-8",	N_("Vietnamese"),
   "wa_BE.UTF-8",	N_("Walloon"),
   "zh_CN.UTF-8",	N_("Chinese (Simplified)"),
@@ -628,7 +626,7 @@ set_locale_flag(gchar *locale)
 
   if(filename)
     {
-      pixmap = gc_net_load_pixmap(filename);
+      pixmap = gdk_pixbuf_new_from_file(filename,NULL);
 
       gnome_canvas_item_set (item_locale_flag,
 			     "pixbuf", pixmap,
