@@ -1,6 +1,4 @@
 /* gcompris - gc_net.h
- *
- * Time-stamp: <2007-08-22 01:21:21 bruno>
  *
  * Copyright (C) 2006 Bruno Coudoin
  *
@@ -34,10 +32,15 @@
 #include "gcompris.h"
 
 void gc_net_init();
-GdkPixbuf *gc_net_load_pixmap(const char *url);
-xmlDocPtr  gc_net_load_xml(const char *url);
 gchar     *gc_net_get_url_from_file(const gchar *format, ...);
-gboolean   gc_net_is_url(const char *url);
 GSList    *gc_net_dir_read_name(const gchar* dir, const gchar *ext);
+void gc_net_destroy();
+
+void gc_cache_init(void);
+void gc_cache_add(gchar *filename);
+gchar* gc_cache_import_pixmap(gchar *filename, gchar *boarddir, gint width, gint height);
+void gc_cache_remove(gchar *filename);
+void gc_cache_save(void);
+void gc_cache_destroy(void);
 
 #endif
