@@ -1,6 +1,4 @@
 /* gcompris - timer.h
- *
- * Time-stamp: <2007-08-22 01:21:26 bruno>
  *
  * Copyright (C) 2001 Pascal Georges
  *
@@ -32,6 +30,7 @@ typedef enum
   GCOMPRIS_TIMER_SAND,
   GCOMPRIS_TIMER_BALLOON,
   GCOMPRIS_TIMER_CLOCK,
+  GCOMPRIS_TIMER_TUX,
 } TimerList;
 
 /* Callback when the timer is completed */
